==> kubernetes-model-1.0.58-sources.jar: annotations/io/fabric8/openshift/api/model/DeploymentConfigListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.String;
import javax.validation.constraints.NotNull;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.util.List;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Object;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ListMetaFluent;
import io.fabric8.kubernetes.api.model.ListMetaBuilder;

public interface DeploymentConfigListFluent<A extends DeploymentConfigListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public A addToItems(DeploymentConfig... items);
    public A removeFromItems(DeploymentConfig... items);
    public List<DeploymentConfig> getItems();
    public A withItems(List<DeploymentConfig> items);
    public A withItems(DeploymentConfig... items);
    public DeploymentConfigListFluent.ItemsNested<A> addNewItem();
    public DeploymentConfigListFluent.ItemsNested<A> addNewItemLike(DeploymentConfig item);
    public String getKind();
    public A withKind(String kind);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public DeploymentConfigListFluent.MetadataNested<A> withNewMetadata();
    public DeploymentConfigListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public DeploymentConfigListFluent.MetadataNested<A> editMetadata();
    public A withNewMetadata(String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,DeploymentConfigFluent<DeploymentConfigListFluent.ItemsNested<N>>{

        
    public N endItem();    public N and();
}
    public interface MetadataNested<N> extends Nested<N>,ListMetaFluent<DeploymentConfigListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/openshift/api/model/DeploymentConfigListFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import javax.validation.constraints.NotNull;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.sundr.builder.annotations.Buildable;
import javax.annotation.Generated;
import io.fabric8.kubernetes.api.model.ListMetaFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.ListMeta;
import io.fabric8.kubernetes.api.model.ListMetaBuilder;
import javax.validation.Valid;
import java.lang.Object;
import lombok.ToString;
import java.util.Map;

public interface DeploymentConfigListFluent<A extends DeploymentConfigListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public A addToItems(DeploymentConfig... items);
    public A removeFromItems(DeploymentConfig... items);
    public List<DeploymentConfig> getItems();
    public A withItems(List<DeploymentConfig> items);
    public A withItems(DeploymentConfig... items);
    public DeploymentConfigListFluent.ItemsNested<A> addNewItem();
    public DeploymentConfigListFluent.ItemsNested<A> addNewItemLike(DeploymentConfig item);
    public String getKind();
    public A withKind(String kind);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public DeploymentConfigListFluent.MetadataNested<A> withNewMetadata();
    public DeploymentConfigListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public DeploymentConfigListFluent.MetadataNested<A> editMetadata();
    public DeploymentConfigListFluent.MetadataNested<A> editOrNewMetadata();
    public DeploymentConfigListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item);
    public A withNewMetadata(String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DeploymentConfigFluent<DeploymentConfigListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ListMetaFluent<DeploymentConfigListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
